==> kartofel-1.1.tar.gz: kartofel-1.1/verify.cc <==
//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <cstdio>
#include <cstdlib>
#include <fcntl.h>
#include <iostream>
#include <sys/types.h>
#include <sys/uio.h>
#include <unistd.h>

#include "game.h"
#include "saved_game.h"

const int NUM_LEVELS = 21;

using namespace std;
using namespace kartofel;

int main(int argc, char** argv)
{
  if (argc < 2) {
    cerr << "Usage: verify <filename>\n";
    exit(0);
  }
  vector<Level> levels;
  for (int i = 1; i <= NUM_LEVELS; i++) {
    char filename[1000];
    snprintf(filename, sizeof(filename), "levels/%d.txt", i);
    Level level;
    LoadLevel(filename, &level);
    levels.push_back(level);
  }
  for (int i = 1; i < argc; i++) {
    char* filename = argv[i];
    string encoded;
    int fd = open(filename, O_RDONLY);
    if (-1 == fd) {
      perror(filename);
      exit(1);
    }
    for (;;) {
      char buf[10000];
      int nb = read(fd, buf, sizeof(buf));
      if (nb < 0) {
        perror("read()");
        exit(1);
      }
      if (nb == 0) {
        if (-1 == close(fd)) {
          perror("close()");
          exit(1);
        }
        break;
      }
      encoded += string(buf, nb);
    }
    SavedGame sg;
    if (sg.Decode(encoded)) {
      int score;
      if (sg.Verify(levels, &score)) {
        cout << filename << ": Score: " << score << endl;
      } else {
        cout << filename << ": Verify() failed.\n";
      }
    } else {
      cout << filename << ": Decode() failed.\n";
    }
  }
}

==> kartofel-1.2.tar.gz: kartofel-1.2/verify.cc <==
//  This file is part of the computer game Kartofel.
//  Copyright (C) 2008 Pawel Aleksander Fedorynski <pfedor@fuw.edu.pl>
//
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
//
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//  GNU General Public License for more details.
//
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <cstdio>
#include <cstdlib>
#include <fcntl.h>
#include <iostream>
#include <sys/types.h>
#include <sys/uio.h>
#include <unistd.h>

#include "game.h"
#include "saved_game.h"

const int NUM_LEVELS = 21;

using namespace std;
using namespace kartofel;

int main(int argc, char** argv)
{
  if (argc < 2) {
    cerr << "Usage: verify <filename>\n";
    exit(0);
  }
  vector<Level> levels;
  for (int i = 1; i <= NUM_LEVELS; i++) {
    char filename[1000];
    snprintf(filename, sizeof(filename), "levels/%d.txt", i);
    Level level;
    LoadLevel(filename, &level);
    levels.push_back(level);
  }
  for (int i = 1; i < argc; i++) {
    char* filename = argv[i];
    string encoded;
    int fd = open(filename, O_RDONLY);
    if (-1 == fd) {
      perror(filename);
      exit(1);
    }
    for (;;) {
      char buf[10000];
      int nb = read(fd, buf, sizeof(buf));
      if (nb < 0) {
        perror("read()");
        exit(1);
      }
      if (nb == 0) {
        if (-1 == close(fd)) {
          perror("close()");
          exit(1);
        }
        break;
      }
      encoded += string(buf, nb);
    }
    SavedGame sg;
    if (sg.Decode(encoded)) {
      int score, starting_level, end_level;
      if (sg.Verify(levels, &starting_level, &end_level, &score)) {
        cout << filename << ": Level " << starting_level << ".."
             << end_level << ", Score: " << score << endl;
      } else {
        cout << filename << ": Verify() failed.\n";
      }
    } else {
      cout << filename << ": Decode() failed.\n";
    }
  }
}
